@@ -153,10 +153,11 @@ function alis_defaults() {
   local DEVICE="$1"
   local ROOT_PASSWORD="$2"
   local SEC_LOCALE="$3"
+  local SWAP_SIZE="$4"
 
   alis_create_partition "$DEVICE"
   alis_pacstrap
-  alis_config_minimum "$ROOT_PASSWORD" "" "$SEC_LOCALE"
+  alis_config_minimum "$ROOT_PASSWORD" "" "$SEC_LOCALE" "$SWAP_SIZE"
 }
 
 function alis_create_partition() {
